==> cattle_grid-0.2.2-py3-none-any.whl: cattle_grid/testing/features/steps/account.py <==
import asyncio

from behave import given, when, then
from behave.api.async_step import async_run_until_complete

from almabtrieb import Almabtrieb

from cattle_grid.config import load_settings
from cattle_grid.database import database
from cattle_grid.account.account import create_account

from cattle_grid.testing.features import publish_as


@given('An account called "{alice}"')
@async_run_until_complete
async def create_account_step(context, alice):
    config = load_settings()
    async with database(db_uri=config.db_uri):
        await create_account(alice, alice)

    context.connections[alice] = Almabtrieb.from_connection_string(
        f"amqp://{alice}:{alice}@rabbitmq/", silent=True
    )
    context.connections[alice].task = asyncio.create_task(
        context.connections[alice].run()
    )

    while not context.connections[alice].connected:
        await asyncio.sleep(0.1)


@given('"{alice}" created an actor called "{alyssa}"')
def create_actor_step(context, alice, alyssa):
    hostname = {"alice": "abel", "bob": "banach", "Bob": "banach"}.get(alyssa, "abel")

    context.execute_steps(
        f"""
        Given "{alice}" created an actor on "{hostname}" called "{alyssa}"
        """
    )


@given('"{alice}" created an actor on "{hostname}" called "{alyssa}"')
@async_run_until_complete
async def create_actor_on_host_step(context, alice, alyssa, hostname):
    result = await context.connections[alice].create_actor(
        base_url=f"http://{hostname}", preferred_username=alyssa
    )
    context.actors[alyssa] = result


@when('"{alice}" deletes the actor "{alyssa}"')
@async_run_until_complete
async def alice_delete_actor_step(context, alice, alyssa):
    alyssa_id = context.actors[alyssa].get("id")

    await publish_as(
        context,
        alice,
        "delete_actor",
        {
            "actor": alyssa_id,
        },
    )


@then('"{alice}" has no actors')
@async_run_until_complete
async def check_no_actors(context, alice):
    response = await context.connections[alice].info()

    assert len(response.actors) == 0, f"Alice has actors {', '.join(response.actors)}"

==> cattle_grid-0.2.8-py3-none-any.whl: cattle_grid/testing/features/steps/account.py <==
import asyncio
import logging

from behave import given, when, then
from behave.api.async_step import async_run_until_complete

from almabtrieb import Almabtrieb

from cattle_grid.config import load_settings
from cattle_grid.database import database
from cattle_grid.account.account import create_account, add_permission

from cattle_grid.testing.features import publish_as

logger = logging.getLogger(__name__)


@given('An account called "{alice}"')
@async_run_until_complete
async def create_account_step(context, alice):
    config = load_settings()
    async with database(db_uri=config.db_uri):
        account = await create_account(alice, alice)
        await add_permission(account, "admin")

    context.connections[alice] = Almabtrieb.from_connection_string(
        f"amqp://{alice}:{alice}@rabbitmq/", silent=True
    )
    context.connections[alice].task = asyncio.create_task(
        context.connections[alice].run()
    )

    for _ in range(10):
        if context.connections[alice].connected:
            return
        logger.info("Connecting")
        await asyncio.sleep(0.1)

    raise RuntimeError("Could not connect")


@given('"{alice}" created an actor called "{alyssa}"')
def create_actor_step(context, alice, alyssa):
    hostname = {"alice": "abel", "bob": "banach", "Bob": "banach"}.get(alyssa, "abel")

    context.execute_steps(
        f"""
        Given "{alice}" created an actor on "{hostname}" called "{alyssa}"
        """
    )


@given('"{alice}" created an actor on "{hostname}" called "{alyssa}"')
@async_run_until_complete
async def create_actor_on_host_step(context, alice, alyssa, hostname):
    result = await context.connections[alice].create_actor(
        base_url=f"http://{hostname}", preferred_username=alyssa
    )
    context.actors[alyssa] = result


@when('"{alice}" deletes the actor "{alyssa}"')
@async_run_until_complete
async def alice_delete_actor_step(context, alice, alyssa):
    alyssa_id = context.actors[alyssa].get("id")

    await publish_as(
        context,
        alice,
        "delete_actor",
        {
            "actor": alyssa_id,
        },
    )


@then('"{alice}" has no actors')
@async_run_until_complete
async def check_no_actors(context, alice):
    response = await context.connections[alice].info()

    assert len(response.actors) == 0, f"Alice has actors {', '.join(response.actors)}"
